Screenshots
===========

`django-debug-toolbar <http://django-debug-toolbar.readthedocs.org/en/latest/>`_ panel

.. image:: screenshots/screenshot1.png



`Wagtail <https://github.com/torchbox/wagtail>`_ admin interface:

.. image:: screenshots/screenshot2.png


.. image:: screenshots/screenshot3.png